# Cringe God
It is a sample version to learn pypi

## Installation
```pip install cringe-god```

## How to use it?
Open terminal and type square and then input the integer

## License

© 2021 Iamrealbhuvi

This repository is licensed under the MIT license. See LICENSE for details.
